<?php
function md_construction_settings($saved_settings, $subtheme_defaults = array()) {

  // Get the default values from the .info file.
  $defaults = md_construction_theme_get_default_settings('md_construction');

  // Merge the saved variables and their default values.
  $settings = array_merge($defaults, $saved_settings);

  /*
   * Create the form using Forms API
   */



  $form['md_construction_general'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('General settings'),
    '#attributes'    => array('id' => 'md-general'),
  );
	
  $form['md_construction_general']['md_construction_color'] = array(
    '#type'          => 'select',
    '#title'         => t('Colour Scheme'),
		'#description'   => t('Select the colour scheme for the theme'),
    '#default_value' => $settings['md_construction_color'],
    '#options'       => array(
                          'blue'   => t('Blue'),
													'orange'   => t('Orange'),
													'purple'   => t('Purple'),
													'green'   => t('Green'),
													'pink'   => t('Pink'),
													'brown'   => t('Brown'),
                        ),
  );
	
  $form['md_construction_general']['md_construction_image_url'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Image URL'),
    '#description'   => t('Enter the link to your comingsoon images, image\'s dimension is more than 1100 × 939 pixels'),
    '#default_value' => $settings['md_construction_image_url'],
  );
	
	$form['md_construction_general']['md_construction_headtitle'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Header title'),
    '#description'   => t('Enter title for your underconstruction page'),
    '#default_value' => $settings['md_construction_headtitle'],
  );
	
	$form['md_construction_general']['md_construction_desc'] = array(
    '#type'          => 'textarea',
    '#title'         => t('Description text'),
    '#description'   => t('Enter description text'),
    '#default_value' => $settings['md_construction_desc'],
  );
	
	$form['md_construction_general']['md_construction_feedburner'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Mail feed Subscription'),
    '#description'   => t('Fill with Google FeedBurner account'),
    '#default_value' => $settings['md_construction_feedburner'],
  );
	
	$form['md_construction_general']['md_construction_twitter'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Twitter username'),
    '#description'   => t('If you want to display twitter icon, fill this with your\'s twitter username'),
    '#default_value' => $settings['md_construction_twitter'],
  );
	
	$form['md_construction_general']['md_construction_facebook'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Facebook link'),
    '#description'   => t('If you want to display facebook icon, fill this with your\'s facebook link without http://www.facebook.com/'),
    '#default_value' => $settings['md_construction_facebook'],
  );

	$form['md_construction_general']['md_construction_analytics'] = array(
    '#type'          => 'textarea',
    '#title'         => t('Google Analytics Code'),
    '#description'   => t('You can paste your Google Analytics or other tracking code in this box. This will be automatically added to the footer.'),
    '#default_value' => $settings['md_construction_analytics'],
  );
	
	$form['md_construction_general']['md_construction_css'] = array(
    '#type'          => 'textarea',
    '#title'         => t('Custom CSS'),
    '#description'   => t('Want to add any custom CSS code? Put in here, and the rest is taken care of. This overrides any other stylesheets. eg: a.button{color:green}'),
    '#default_value' => $settings['md_construction_css'],
  );

  // Return the form
  return $form;
}


function _md_construction_theme(&$existing, $type, $theme, $path) {
  // Each theme has two possible preprocess functions that can act on a hook.
  // This function applies to every hook.
  $functions[0] = $theme . '_preprocess';
  // Inspect the preprocess functions for every hook in the theme registry.
  // @TODO: When PHP 5 becomes required (Basic 7.x), use the following faster
  // implementation: foreach ($existing AS $hook => &$value) {}
  foreach (array_keys($existing) AS $hook) {
    // Each theme has two possible preprocess functions that can act on a hook.
    // This function only applies to this hook.
    $functions[1] = $theme . '_preprocess_' . $hook;
    foreach ($functions AS $key => $function) {
      // Add any functions that are not already in the registry.
      if (function_exists($function) && !in_array($function, $existing[$hook]['preprocess functions'])) {
        // We add the preprocess function to the end of the existing list.
        $existing[$hook]['preprocess functions'][] = $function;
      }
    }
  }

  // Since we are rebuilding the theme registry and the theme settings' default
  // values may have changed, make sure they are saved in the database properly.
  md_construction_theme_get_default_settings($theme);

  // If we are auto-rebuilding the theme registry, warn about feature.
  if (theme_get_setting('md_construction_rebuild_registry')) {
    drupal_set_message(t('The theme registry has been rebuilt. <a href="!link">Turn off</a> this feature on production websites.', array('!link' => base_path() . 'admin/build/themes/settings/' . $GLOBALS['theme'])), 'warning');
  }

  // Since we modify the $existing cache directly, return nothing.
  return array();
}


function md_construction_theme_get_default_settings($theme) {
  $themes = list_themes();

  // Get the default values from the .info file.
  $defaults = !empty($themes[$theme]->info['settings']) ? $themes[$theme]->info['settings'] : array();

  if (!empty($defaults)) {
    // Get the theme settings saved in the database.
    $settings = theme_get_settings($theme);
    // Don't save the toggle_node_info_ variables.
    if (module_exists('node')) {
      foreach (node_get_types() as $type => $name) {
        unset($settings['toggle_node_info_' . $type]);
      }
    }
    // Save default theme settings.
    variable_set(
      str_replace('/', '_', 'theme_' . $theme . '_settings'),
      array_merge($defaults, $settings)
    );
    // If the active theme has been loaded, force refresh of Drupal internals.
    if (!empty($GLOBALS['theme_key'])) {
      theme_get_setting('', TRUE);
    }
  }

  // Return the default settings.
  return $defaults;
}
